==> vtigercrm-5.1.0.tgz: modules/Services/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Services',
'SINGLE_Services'=>'Service',
'LBL_LIST_SERVICE_NAME'=>'Service Name',
'LBL_PRICEBOOK'=>'Price Book:',
'LBL_PRICEBOOK_INFORMATION'=>'Price Book Information:',
'LBL_PRICING_INFORMATION'=>'Pricing Information:',
'LBL_LIST_FORM_TITLE'=>'Service List',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Price Book List',
'LBL_SERVICE_UNIT_PRICE'=>'Unit Price',
'LBL_PB_LIST_PRICE'=>'List Price',
'LBL_SERVICE_INFORMATION'=>'Service Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',

'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Add To Price Books',

'Services'=>'Services',
'Service Name'=>'Service Name',
'Service Active'=>'Active',
'Service Category'=>'Category',
'Service No'=>'Service No',
'Owner'=>'Owner',
'Days'=>'Days',
'Hours'=>'Hours',
'Incidents'=>'Incidents',
'No of Units'=>'No of Units',
'Commission Rate'=>'Commission Rate (%)',
'Unit Price'=>'Unit Price',
'Price'=>'Price',
'Support Start Date'=>'Support Start Date',
'Support Expiry Date'=>'Support Expiry Date',
'Sales Start Date'=>'Sales Start Date',
'Sales End Date'=>'Sales End Date',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Related To'=>'Related To',
'Usage Unit'=>'Usage Unit',
'Currency'=>'Currency',
'Tax Class'=>'Tax Class',
'Website'=>'Website',
'Description'=>'Description',

'Price Book Name'=>'Price Book Name',

'LBL_NO_TAXES_ASSOCIATED'=>'No taxes associated with this service',
);

?>

==> vtigercrm-5.3.0p0.tgz: modules/Services/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Services',
'SINGLE_Services'=>'Service',
'LBL_LIST_SERVICE_NAME'=>'Service Name',
'LBL_PRICEBOOK'=>'Price Book:',
'LBL_PRICEBOOK_INFORMATION'=>'Price Book Information:',
'LBL_PRICING_INFORMATION'=>'Pricing Information:',
'LBL_LIST_FORM_TITLE'=>'Service List',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Price Book List',
'LBL_SERVICE_UNIT_PRICE'=>'Unit Price',
'LBL_PB_LIST_PRICE'=>'List Price',
'LBL_SERVICE_INFORMATION'=>'Service Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',

'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Add To Price Books',

'Services'=>'Services',
'Service Name'=>'Service Name',
'Service Active'=>'Active',
'Service Category'=>'Category',
'Service No'=>'Service No',
'Owner'=>'Owner',
'Days'=>'Days',
'Hours'=>'Hours',
'Incidents'=>'Incidents',
'No of Units'=>'No of Units',
'Commission Rate'=>'Commission Rate (%)',
'Unit Price'=>'Unit Price',
'Price'=>'Price',
'Support Start Date'=>'Support Start Date',
'Support Expiry Date'=>'Support Expiry Date',
'Sales Start Date'=>'Sales Start Date',
'Sales End Date'=>'Sales End Date',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Related To'=>'Related To',
'Usage Unit'=>'Usage Unit',
'Currency'=>'Currency',
'Tax Class'=>'Tax Class',
'Website'=>'Website',
'Description'=>'Description',

'Price Book Name'=>'Price Book Name',

'LBL_NO_TAXES_ASSOCIATED'=>'No taxes associated with this service',
'--None--'=>'--None--',
'Installation'=>'Installation',
'Migration'=>'Migration',
'Customization'=>'Customization',
'Training'=>'Training',

);

?>
